@@ -1,9 +1,8 @@
 import os
 
 
-class Plugin():
-
-    def __init__(self, prefix=''):
+class Plugin:
+    def __init__(self, prefix=""):
         self.name = self.__class__.__name__
         self.miner = None
         self.prefix = prefix
@@ -14,7 +13,7 @@ class Plugin():
     def set_miner(self, miner):
         self.miner = miner
 
-    def notify(self, message, _type='info'):
+    def notify(self, message, _type="info"):
         message = f"[{self.name}] {message}"
         self.miner.notify(message, _type)
 
@@ -24,15 +23,18 @@ class Plugin():
         return getattr(self.miner, key)
 
     def print_txt(self, printable, name):
-        with open(self.plugin_file(f'{name}.txt'), 'a') as f:
-            print(f'================ Epoch {self.current_epoch} ================\n', file=f)
+        with open(self.plugin_file(f"{name}.txt"), "a") as f:
+            print(
+                f"================ Epoch {self.current_epoch} ================\n",
+                file=f,
+            )
             print(printable, file=f)
             print("\n\n", file=f)
 
     @property
     def plugin_dir(self):
-        if hasattr(self, '_plugin_dir'):
-            return getattr(self, '_plugin_dir')
+        if hasattr(self, "_plugin_dir"):
+            return getattr(self, "_plugin_dir")
 
         plugin_dir = os.path.join(self.code_dir, self.__class__.__name__)
         try:
@@ -46,10 +48,12 @@ class Plugin():
         return os.path.join(self.plugin_dir, name)
 
     def create_sheet_column(self, key, name):
-        self.miner.create_sheet_column(f'{self.prefix}{key}', f'{self.prefix}{name}')
+        self.miner.create_sheet_column(f"{self.prefix}{key}", f"{self.prefix}{name}")
 
     def update_sheet(self, key, value):
-        self.miner.update_sheet(f'{self.prefix}{key}', value)
+        self.miner.update_sheet(f"{self.prefix}{key}", value)
 
     def scalars(self, values, graph):
-        return self.miner.drawer.scalars(self.miner.current_epoch, values, f'{self.prefix}{graph}')
+        return self.miner.drawer.scalars(
+            self.miner.current_epoch, values, f"{self.prefix}{graph}"
+        )
